==> Paws-0.30.tar.gz: Paws-0.30/lib/Paws/RedShift/DeleteEventSubscription.pm <==

package Paws::RedShift::DeleteEventSubscription;
  use Moose;
  has SubscriptionName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteEventSubscription');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::DeleteEventSubscription - Arguments for method DeleteEventSubscription on Paws::RedShift

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteEventSubscription on the 
Amazon Redshift service. Use the attributes of this class
as arguments to method DeleteEventSubscription.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteEventSubscription.

As an example:

  $service_obj->DeleteEventSubscription(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> SubscriptionName => Str

The name of the Amazon Redshift event notification subscription to be
deleted.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteEventSubscription in L<Paws::RedShift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/RedShift/DeleteEventSubscription.pm <==

package Paws::RedShift::DeleteEventSubscription;
  use Moose;
  has SubscriptionName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteEventSubscription');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::DeleteEventSubscription - Arguments for method DeleteEventSubscription on L<Paws::RedShift>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteEventSubscription on the
L<Amazon Redshift|Paws::RedShift> service. Use the attributes of this class
as arguments to method DeleteEventSubscription.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteEventSubscription.

=head1 SYNOPSIS

    my $redshift = Paws->service('RedShift');
    $redshift->DeleteEventSubscription(
      SubscriptionName => 'MyString',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/redshift/DeleteEventSubscription>

=head1 ATTRIBUTES


=head2 B<REQUIRED> SubscriptionName => Str

The name of the Amazon Redshift event notification subscription to be
deleted.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteEventSubscription in L<Paws::RedShift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
